#include "videoplaybackwindow.h"
#include "../base/session.h"
#include <QVBoxLayout>

VideoPlaybackWindow::VideoPlaybackWindow(Session *session, QList< QSharedPointer<VideoItem> > playlist, QWidget *parent) :
    StackedWindow(session, parent),
    m_oldOrientation(m_session->settings()->screenOrientation()),
    m_videoWidget(new VideoWidget(this)),
    m_player(new QMediaPlayer(this)),
    m_controls(new VideoControls(m_session, m_player, playlist, this))
{
    this->setWindowState(Qt::WindowFullScreen);
    this->setWindowTitle(tr("Now playing"));
    this->setCentralWidget(new QWidget(this));

    QVBoxLayout *vbox = new QVBoxLayout(this->centralWidget());
    vbox->setContentsMargins(0, 0, 0, 0);
    vbox->setSpacing(0);
    vbox->addWidget(m_videoWidget);
    vbox->addWidget(m_controls);

    m_session->settings()->setScreenOrientation(ScreenOrientation::LockLandscape);
    m_session->preventDisturb(true);

    m_player->setVideoOutput(m_videoWidget);
    m_player->setVolume(100);

    m_controls->hide();

    this->connect(m_videoWidget, SIGNAL(clicked()), this, SLOT(toggleControls()));
    this->connect(m_controls, SIGNAL(back()), this, SLOT(close()));
}

VideoPlaybackWindow::~VideoPlaybackWindow() {
    m_player->stop();
    m_session->settings()->setScreenOrientation(m_oldOrientation);
    m_session->preventDisturb(false);
}

void VideoPlaybackWindow::toggleControls() {
    m_controls->setVisible(!m_controls->isVisible());
}

bool VideoPlaybackWindow::event(QEvent *e) {
    switch (e->type()) {
    case QEvent::WindowActivate:
        m_session->preventDisturb(m_player->state() == QMediaPlayer::PlayingState);
        break;
    case QEvent::WindowDeactivate:
        m_session->preventDisturb(false);
        break;
    }

    return StackedWindow::event(e);
}

void VideoPlaybackWindow::keyPressEvent(QKeyEvent *event) {
    switch (event->key()) {
    case Qt::Key_F:
        this->toggleControls();
        break;
    case Qt::Key_Backspace:
        this->close();
        break;
    default:
        m_controls->keyPressEvent(event);
        break;
    }
}
